pyxmpp2.presence

Package pyxmpp2 :: Module presence |
[hide private]

# Module presence

Presence XMPP stanza handling

Normative reference:
  - RFC 3920

Classes | [hide private]
| Presence <presence /> stanza.

Variables | [hide private]
| PRESENCE_TYPES = ``(``'``available``'``,` `'``unavailable``'``,` `'``probe``'``,` `'``subscr``...``
| ACCEPT_RESPONSES = ``{``'``subscribe``'``:` `'``subscribed``'``,` `'``subscribed``'``:` `'``...``
| DENY_RESPONSES = ``{``'``subscribe``'``:` `'``unsubscribed``'``,` `'``subscribed``'``:` `'``...``

Variables Details | [hide private]

  ### PRESENCE_TYPES Value:
      ('available',
       'unavailable',
       'probe',
       'subscribe',
       'unsubscribe',
       'subscribed',
       'unsubscribed',
       'invisible',
      ...

  ### ACCEPT_RESPONSES Value:
      {'subscribe': 'subscribed',
       'subscribed': 'subscribe',
       'unsubscribe': 'unsubscribed',
       'unsubscribed': 'unsubscribe'}

  ### DENY_RESPONSES Value:
      {'subscribe': 'unsubscribed',
       'subscribed': 'unsubscribe',
       'unsubscribe': 'subscribed',
       'unsubscribed': 'subscribe'}